
Session cookies (Domain)
-------

**Description:**

The Domain option allows you to specify whether or not to send the cookie to subdomains. 


**Solution:**

Setting &quot;www.example.com&quot; will mean only the exact domain "www.example.com" will 
be matched, while &quot;.example.com&quot; will also match again any 
subdomaim (forums.example.com, blog.example.com).

	